<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:iwmo="http://www.istandaarden.nl/iwmo/3_2/basisschema/schema"
				xmlns:wmo301="http://www.istandaarden.nl/iwmo/3_2/wmo301/schema"
>

	<!-- iWmo 3.2 TR302 version 2.10.5 (2022-09-30) -->

	<xsl:import href="../common/basis.xsl"/>
	<xsl:template match="*" mode="TR302"/>
	<xsl:template match="*" mode="check">
		<xsl:apply-templates select="*" mode="TR302"/>
	</xsl:template>

	<xsl:template match="wmo301:ToegewezenProduct" mode="TR302">
		<xsl:call-template name="tr302"/>
	</xsl:template>

	<xsl:template name="tr302">
		<xsl:param name="pThis" select="."/>
		<xsl:param name="pList" select="preceding-sibling::*"/>

		<xsl:variable name="vIgnoreSelf">
			<xsl:call-template name="ignoreForTR302"/>
		</xsl:variable>

		<xsl:if test="$vIgnoreSelf != 'true'">
			<xsl:for-each select="$pList">
				<xsl:variable name="vIgnorePredecessor">
					<xsl:call-template name="ignoreForTR302"/>
				</xsl:variable>
				<xsl:if test="$vIgnorePredecessor != 'true' and (
	                	(
							($pThis/wmo301:Product/iwmo:Code and current()/wmo301:Product/iwmo:Code and $pThis/wmo301:Product/iwmo:Code = current()/wmo301:Product/iwmo:Code) and
	                		($pThis/wmo301:Product/iwmo:Categorie and current()/wmo301:Product/iwmo:Categorie and $pThis/wmo301:Product/iwmo:Categorie = current()/wmo301:Product/iwmo:Categorie)
	                	) or
	                	(
	                		(not($pThis/wmo301:Product/iwmo:Code) or not(current()/wmo301:Product/iwmo:Code)) and
	                		($pThis/wmo301:Product/iwmo:Categorie and current()/wmo301:Product/iwmo:Categorie and $pThis/wmo301:Product/iwmo:Categorie = current()/wmo301:Product/iwmo:Categorie)
	                	) or
	                	(
	                		(not($pThis/wmo301:Product/iwmo:Code) and not($pThis/wmo301:Product/iwmo:Categorie)) or
	                		(not(current()/wmo301:Product/iwmo:Code) and not(current()/wmo301:Product/iwmo:Categorie))
	                	)
	                )">
					<!-- RFC iWmo 2021-001 -->
					<xsl:variable name="thisIsHulpmiddel">
						<xsl:call-template name="testvalue">
							<xsl:with-param name="pElement" select="$pThis/wmo301:Product/iwmo:Categorie"/>
							<xsl:with-param name="pValues">11, 12, 13, 14</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="otherIsHulpmiddel">
						<xsl:call-template name="testvalue">
							<xsl:with-param name="pElement" select="current()/wmo301:Product/iwmo:Categorie"/>
							<xsl:with-param name="pValues">11, 12, 13, 14</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="isOverlay">
						<xsl:call-template name="isPeriodOverlay">
							<xsl:with-param name="pThis" select="$pThis"/>
							<xsl:with-param name="pOther" select="current()"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$thisIsHulpmiddel != 'true' and $otherIsHulpmiddel != 'true' and $isOverlay = 'true'">
						<xsl:call-template name="addError">
							<xsl:with-param name="pElements" select="$pThis | current()"/>
							<xsl:with-param name="pRule">TR302</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>

	<xsl:template name="ignoreForTR302">
		<xsl:param name="pThis" select="."/>
		<xsl:choose>
			<xsl:when
					test="(wmo301:RedenWijziging/text() = '01' or wmo301:RedenWijziging/text() = '13') and wmo301:Einddatum/. and normalize-space(wmo301:Einddatum/text()) != ''">
				<xsl:choose>
					<xsl:when
							test="translate(wmo301:Ingangsdatum/text(), '-', '') = translate(wmo301:Einddatum/text(), '-', '')">
						<xsl:value-of select="true()"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="false()"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="false()"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
