<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:iwmo="http://www.istandaarden.nl/iwmo/3_2/basisschema/schema"
				xmlns:wmo325="http://www.istandaarden.nl/iwmo/3_2/wmo325/schema"
>

	<!-- iWmo 3.2 TR342 version 2.10.5 (2022-09-30) -->

	<xsl:import href="../common/basis.xsl"/>
	<xsl:template match="*" mode="TR342"/>
	<xsl:template match="*" mode="check">
		<xsl:apply-templates select="*" mode="TR342"/>
	</xsl:template>

	<xsl:template match="wmo325:DeclaratieAntwoord" mode="TR342">
		<!-- Bereken SaldoIngediendeBedragregel -->
		<xsl:variable name="IngediendTotaalDebet"
					  select="sum(./wmo325:Clienten/wmo325:Client/wmo325:Prestaties/wmo325:Prestatie/wmo325:IngediendBedrag[./iwmo:DebetCredit/text() = 'D']/iwmo:Bedrag)"/>
		<xsl:variable name="IngediendTotaalCredit"
					  select="sum(./wmo325:Clienten/wmo325:Client/wmo325:Prestaties/wmo325:Prestatie/wmo325:IngediendBedrag[./iwmo:DebetCredit/text() = 'C']/iwmo:Bedrag)"/>
		<xsl:variable name="SaldoIngediendeBedragregel" select="$IngediendTotaalDebet - $IngediendTotaalCredit"/>

		<!-- Maak van ToegekendTotaalBedrag een negatief getal als ToegekendDebetCredit waarde C heeft -->
		<xsl:variable name="ToegekendTotaalBedragDC">
			<xsl:choose>
				<xsl:when test="./wmo325:TotaalToegekendBedrag/iwmo:DebetCredit/text() = 'C' ">
					<xsl:value-of select='number(./wmo325:TotaalToegekendBedrag/iwmo:TotaalBedrag/text()) * -1'/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select='number(./wmo325:TotaalToegekendBedrag/iwmo:TotaalBedrag/text())'/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<!-- Maak van IngediendTotaalBedrag een negatief getal als IngediendDebetCredit waarde C heeft -->
		<xsl:variable name="IngediendTotaalBedragDC">
			<xsl:choose>
				<xsl:when test="./wmo325:TotaalIngediendBedrag/iwmo:DebetCredit/text() = 'C' ">
					<xsl:value-of select="number(./wmo325:TotaalIngediendBedrag/iwmo:TotaalBedrag/text()) * -1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="number(./wmo325:TotaalIngediendBedrag/iwmo:TotaalBedrag/text())"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<!-- Bepaal verschil F:= IngediendTotaalBedrag minus ToegekendTotaalBedrag-->
		<xsl:variable name="VerschilHeaderTotalen" select="$IngediendTotaalBedragDC - $ToegekendTotaalBedragDC"/>

		<!-- Controleren of verschil E overeenkomt met verschil F bedragen -->
		<xsl:choose>
			<xsl:when
					test="count(ancestor-or-self::wmo325:DeclaratieAntwoord/wmo325:RetourCodes/*[local-name() = 'RetourCode'][text() != '0200' and text() != '8001']) = 0">
				<xsl:if test="normalize-space($SaldoIngediendeBedragregel) != normalize-space($VerschilHeaderTotalen)">
					<xsl:call-template name="addError">
						<xsl:with-param name="pRule">TR342</xsl:with-param>
						<xsl:with-param name="pCode">0001</xsl:with-param>
						<xsl:with-param name="pElements"
										select="wmo325:TotaalToegekendBedrag | wmo325:TotaalIngediendBedrag "/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$ToegekendTotaalBedragDC != 0">
					<xsl:call-template name="addError">
						<xsl:with-param name="pRule">TR342</xsl:with-param>
						<xsl:with-param name="pCode">0001</xsl:with-param>
						<xsl:with-param name="pElements" select="wmo325:TotaalToegekendBedrag"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>
