<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:iwmo="http://www.istandaarden.nl/iwmo/3_2/basisschema/schema"
                xmlns:wmo323="http://www.istandaarden.nl/iwmo/3_2/wmo323/schema"
>

    <!-- iJw 3.2 TR416 version 2.10.5 (2022-09-30) -->

    <xsl:import href="../common/basis.xsl"/>
    <xsl:template match="*" mode="TR416"/>
    <xsl:template match="*" mode="check">
        <xsl:apply-templates select="*" mode="TR416"/>
    </xsl:template>

    <xsl:template match="wmo323:Prestatie[wmo323:IngediendBedrag/iwmo:DebetCredit = 'D']" mode="TR416">
            <xsl:call-template name="checkTR416" />
    </xsl:template>

    <xsl:template name="checkTR416">
        <xsl:variable name="pThis" select="."/>
        <xsl:variable name="vBeginDatum" select="$pThis/wmo323:ProductPeriode/iwmo:Begindatum"/>
        <xsl:variable name="vEindDatum" select="$pThis/wmo323:ProductPeriode/iwmo:Einddatum"/>
        <xsl:variable name="vProductCategorie" select="$pThis/wmo323:ProductCategorie"/>
        <xsl:variable name="vToewijzingNummer" select="$pThis/wmo323:ToewijzingNummer"/>
        <xsl:variable name="vProductCode" select="$pThis/wmo323:ProductCode"/>
        <xsl:variable name="vList" select="preceding-sibling::*[
        wmo323:ProductPeriode/iwmo:Begindatum = $vBeginDatum and
        wmo323:ProductPeriode/iwmo:Einddatum = $vEindDatum and
        wmo323:ProductCategorie = $vProductCategorie and
        wmo323:ToewijzingNummer = $vToewijzingNummer and
        wmo323:ProductCode = $vProductCode
        ]"/>

        <xsl:for-each select="$vList">
            <xsl:variable name="siblingBeginDatum" select="current()/wmo323:ProductPeriode/iwmo:Begindatum"/>
            <xsl:variable name="siblingEindDatum" select="current()/wmo323:ProductPeriode/iwmo:Einddatum"/>
            <xsl:variable name="siblingProductCategorie" select="current()/wmo323:ProductCategorie"/>
            <xsl:variable name="siblingToewijzingNummer" select="current()/wmo323:ToewijzingNummer"/>
            <xsl:variable name="siblingProductCode" select="current()/wmo323:ProductCode"/>
            <xsl:variable name="siblingDebetCredit" select="current()/wmo323:IngediendBedrag/iwmo:DebetCredit"/>

            <xsl:if test="normalize-space($vBeginDatum) = normalize-space($siblingBeginDatum) and
                          normalize-space($vEindDatum) = normalize-space($siblingEindDatum) and
                          normalize-space($vProductCategorie) = normalize-space($siblingProductCategorie) and
                          normalize-space($vToewijzingNummer) = normalize-space($siblingToewijzingNummer) and
                          normalize-space($vProductCode) = normalize-space($siblingProductCode) and
                          normalize-space($siblingDebetCredit) = 'D'">
                <xsl:call-template name="addError">
                    <xsl:with-param name="pElements" select="$pThis | current()"/>
                    <xsl:with-param name="pRule">
                        TR416
                    </xsl:with-param>

                </xsl:call-template>
            </xsl:if>

        </xsl:for-each>
    </xsl:template>

</xsl:stylesheet>
